@@ -10,7 +10,7 @@ use WebService::SSLLabs::Host();
 use WebService::SSLLabs::Endpoint();
 use WebService::SSLLabs::StatusCodes();
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 sub _MINIMUM_ETA_TIME { return 10; }
 
@@ -162,6 +162,19 @@ sub get_status_codes {
     }
 }
 
+sub get_root_certs_raw {
+    my ($self)   = @_;
+    my $url      = $self->{url} . 'getRootCertsRaw';
+    my $response = $self->{ua}->get($url);
+    if ( $response->is_success() ) {
+        $self->_parse_success($response);
+        return $response->decoded_content();
+    }
+    else {
+        Carp::croak( "Failed to retrieve $url:" . $response->status_line() );
+    }
+}
+
 1;    # End of WebService::SSLLabs
 __END__
 
@@ -171,7 +184,7 @@ WebService::SSLLabs - Analyze the configuration of any SSL web server on the pub
 
 =head1 VERSION
 
-Version 0.20
+Version 0.21
 
 =head1 SYNOPSIS
 
@@ -267,6 +280,10 @@ This call will return the maximum number of concurrent assessments the client is
 
 This call will return the number of ongoing assessments submitted by this client.  This information is only available after a L<analyze|WebService::SSLLabs/"analyze">, L<get_endpoint_data|WebService::SSLLabs/"get_endpoint_data">, L<info|WebService::SSLLabs/"info"> or L<get_status_codes|WebService::SSLLabs/"get_status_codes"> call has been made.  It is retrieved from the X-Current-Assessments header in a successful API call.
 
+=head2 get_root_certs_raw
+
+This call will return a scalar containing the root certificates used for trust validation.
+
 =head1 DIAGNOSTICS
 
 =over
@@ -287,6 +304,7 @@ WebService::SSLLabs requires the following non-core modules
 
   JSON
   LWP::UserAgent
+  URI
   URI::Escape
 
 =head1 INCOMPATIBILITIES
