@@ -9,7 +9,7 @@ use WebService::SSLLabs::Protocol();
 use WebService::SSLLabs::Chain();
 use WebService::SSLLabs::Key();
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 sub new {
     my ( $class, $json ) = @_;
@@ -246,6 +246,26 @@ sub logjam {
     return $self->{logjam} ? 1 : 0;
 }
 
+sub chacha20_preference {
+    my ($self) = @_;
+    return $self->{chaCha20Preference} ? 1 : 0;
+}
+
+sub hsts_policy {
+    my ($self) = @_;
+    return $self->{hstsPolicy};
+}
+
+sub hpkp_policy {
+    my ($self) = @_;
+    return $self->{hpkpPolicy};
+}
+
+sub hpkp_ro_policy {
+    my ($self) = @_;
+    return $self->{hpkpRoPolicy};
+}
+
 1;
 __END__
 
@@ -255,7 +275,7 @@ WebService::SSLLabs::EndpointDetails - EndpointDetails object
 
 =head1 VERSION
 
-Version 0.20
+Version 0.21
 
 =head1 SUBROUTINES/METHODS
 
@@ -537,6 +557,22 @@ true if the DH ephemeral server value is reused.
 
 true if the server uses DH parameters weaker than 1024 bits.
 
+=head2 chacha20_preference
+
+true if the server takes into account client preferences when deciding if to use ChaCha20 suites
+
+=head2 hsts_policy
+
+returns server's HSTS policy as a HASH. Experimental.
+
+=head2 hpkp_policy
+
+returns server's HPKP policy as a HASH. Experimental.
+
+=head2 hpkp_ro_policy
+
+returns server's HPKP Report Only policy as a HASH. Experimental.
+
 =head1 DIAGNOSTICS
 
 None
